@@ -19,11 +19,16 @@
 
 -f : 输出html文件名(默认是 作者-帖子标题.html)
 
--T : 生成的贴子不加楼层目录(默认是加楼层目录)
+
+-P : 取 top n 页
+
+-F : 取 top n 楼
+
+-W : 跟贴至少要 n 个字
 
 -U : 只看楼主(默认是取出所有楼层，不只楼主)
 
--C : 跟帖内容不能少于多少字
+-T : 生成的贴子不加楼层目录(默认是加楼层目录)
 
 =cut
 
@@ -42,7 +47,7 @@ use vars qw/%OPT/;
 
 $|=1;
 
-getopt( 'sufTUC', \%OPT );
+getopt( 'sufPFWUT', \%OPT );
 
 
 my $tiezi_url = $OPT{u};
@@ -52,18 +57,11 @@ print "\rget tiezi to html : $tiezi_url";
 my $xs = Tiezi::Robot->new();
 $xs->set_parser($OPT{s} || $tiezi_url) ;
 $xs->set_packer('HTML');
-$xs->get_tiezi($tiezi_url, { 'skip_toc' => $OPT{T}, 'skip_floor' => sub { skip_floor(@_, \%OPT); }, });
-
-sub skip_floor {
-    my ($t, $f, $o) = @_;
-
-    return 1 if(exists $o->{U} and $f->{name} ne $t->{topic}{name});
-
-    if($o->{C}){
-        my $c = $f->{content};
-        $c=~s/<.+?>//sg;
-        return 1 if(length($c) < $o->{C});    
-    }
-
-    return 0;
-}
+my $o = { 
+        'with_toc' => $OPT{T} // 1, 
+        'only_poster' => $OPT{U} // undef, 
+        'min_word_num' => $OPT{W} // undef, 
+        'max_page_num' => $OPT{P} // undef, 
+        'max_floor_num' => $OPT{F} // undef,
+};
+$xs->get_tiezi($tiezi_url, $o);
